#import "MSCustomRouteViewController.h"

@interface MSCustomRouteViewController ()
@property (nonatomic, strong) MRPathOverlay *routeOverlay;
@end

@implementation MSCustomRouteViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.mapView.mapKey = [MREditorKey keyForMap:[MSExampleHost mapID] app:[MSExampleHost appID]];
        self.mapView.showsUserLocation = YES;
        self.mapView.showsRoutePath = NO;
    }
    return self;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Custom Route Line";
}

+ (NSString *)exampleInfo {
    return @"Example of how to customize the route path.\n\n"
    @"• `Directions` button to start and stop directions from the selected placemark.\n"
    @"• The default route path is now a red line of width 2.\n";
}

#pragma mark - MRMapViewDelegate

- (MRPathRenderer *)mapView:(MRMapView *)mapView rendererForOverlay:(MRPathOverlay *)overlay {
    MRPathRenderer *renderer = [[MRPathRenderer alloc] initWithOverlay:overlay];
    renderer.strokeColor = [UIColor redColor];
    renderer.lineCap = kCGLineCapRound;
    renderer.lineJoin = kCGLineJoinRound;
    renderer.lineWidth = 2;
    return renderer;
}

- (void)mapViewDidFinishLoadingMap:(MRMapView *)mapView {
    [super mapViewDidFinishLoadingMap:mapView];
    [self reloadRouteOverlay];
}

- (void)mapView:(MRMapView *)mapView routeDidChange:(MRRoute *)route {
    [super mapView:mapView routeDidChange:route];
    [self reloadRouteOverlay];
}

#pragma mark - Internal

- (void)reloadRouteOverlay {
    [self.mapView removeOverlay:self.routeOverlay];
    self.routeOverlay = nil;
    if (self.mapView.route) {
        UIBezierPath *path = [UIBezierPath bezierPath];
        for (MRRouteStep *i in self.mapView.route.steps) {
            if ([i.mapKey isEqualToKey:self.mapView.mapKey]) {
                [path appendPath:i.path];
            }
        }
        self.routeOverlay = [[MRPathOverlay alloc] initWithPath:path.CGPath];
        [self.mapView addOverlay:self.routeOverlay];
    }
}

@end
