#import "MSFriendMapController.h"

@interface MSFriendMapController () <MRSharingSessionDelegate>
@property (nonatomic, strong) MRSharingSession *session;
@property (nonatomic, strong) NSArray *friends;
@end

@implementation MSFriendMapController

- (id)initWithSession:(MRSharingSession *)session {
    if ((self = [super init])) {
        self.session = session;
        self.session.delegate = self;
        self.mapView.mapKey = [MREditorKey keyForMap:[MSExampleHost mapID] app:[MSExampleHost appID]];
        self.mapView.showsUserLocation = YES;
    }
    return self;
}

#pragma mark - UIViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self reloadAnnotations];
}

#pragma mark - MRMapViewDelegate

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    MRAnnotationView *superAnnotationView = [super mapView:mapView viewForAnnotation:annotation];
    if ([annotation isKindOfClass:[MRFriend class]]) {
        MRFriendAnnotationView *annotationView = (id)[self.mapView dequeueReusableAnnotationViewWithIdentifier:@"FriendAnnotation"];
        if (!annotationView) {
            annotationView = [[MRFriendAnnotationView alloc] initWithAnnotation:annotation reuseIdentifier:@"FriendAnnotation"];
        }
        return annotationView;
    }
    return superAnnotationView;
}

- (void)mapViewDidFinishLoadingMap:(MRMapView *)mapView {
    [super mapViewDidFinishLoadingMap:mapView];
    [self reloadAnnotations];
}

#pragma mark - MRSharingSessionDelegate

- (void)sharingSession:(MRSharingSession *)session didFailWithError:(NSError *)error {
    // no-op
}

- (void)sharingSession:(MRSharingSession *)session friendsDidUpdate:(NSArray <MRFriend *> *)friends {
    self.friends = friends;
    [self reloadAnnotations];
}

#pragma mark - Internal

- (void)reloadAnnotations {
    if (!self.mapView) {
        return;
    }

    NSMutableArray *onMap = [NSMutableArray array];
    for (MRFriend *i in self.friends) {
        if ([i.location.mapKey isEqual:self.mapView.mapKey]) {
            [onMap addObject:i];
        }
    }

    NSMutableArray *toAdd = [onMap mutableCopy];
    NSMutableArray *toRemove = [NSMutableArray array];
    for (MRFriend *i in self.mapView.annotations) {
        MRFriend *found = nil;
        for (MRFriend *j in onMap) {
            if ([i.key isEqual:j.key]) {
                found = j;
                break;
            }
        }
        if (found) {
            i.location = found.location;
            [toAdd removeObjectIdenticalTo:found];
        } else {
            [toRemove addObject:i];
        }
    }

    [self.mapView removeAnnotations:toRemove];
    [self.mapView addAnnotations:toAdd];
}

@end
