//
//  MSConvertCoordinatesViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/18/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSConvertCoordinatesViewController: MRMapViewController, MSExampleViewController {
    private lazy var markerView: UIView = {
        let markerView = UIView(frame: CGRect(x: 0, y: 0, width: 10, height: 10))
        markerView.backgroundColor = UIColor.red
        return markerView
    }()

    private lazy var userAnnotation: MRPointAnnotation = {
        let userAnnotation = MRPointAnnotation()
        userAnnotation.point = CGPoint(x: 0, y: 0)
        return userAnnotation
    }()
    
    convenience init() {
        self.init(nibName:nil, bundle:nil)
        mapView.mapKey = MREditorKey(forMap: MSExampleHost.mapID(), app: MSExampleHost.appID())
    }

    override func viewDidLoad() {
        super.viewDidLoad()
        mapView.addAnnotation(userAnnotation)
        mapView.addSubview(markerView)

        let button0 = UIBarButtonItem(title: "Position Markers", style: .plain, target: self, action: #selector(layoutMarkers))
        navigationItem.rightBarButtonItems = [button0]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Convert Coordinates"
    }

    static func exampleDetail() -> String {
        return """
        Example of how to convert to and from the map coordinate system.
        
        • Button to reposition red and blue markers.
        • Blue annotation is moved to the center of the map view.
        • Red view is moved above the 'KFC' placemark.
        """
    }

    // MARK: - Action

    @objc private func layoutMarkers() {
        for case let placemark as MRPlacemark in mapView.placemarks {
            if let title = placemark.title, title == "KFC" {
                markerView.center = mapView.convertMapPoint(placemark.point, toPointTo: view)
                view.bringSubviewToFront(markerView)
                userAnnotation.point = mapView.convert(CGPoint(x: view.bounds.midX, y: view.bounds.midY), toMapPointFrom: view)
                break
            }
        }
    }

    // MARK: - MRMapViewDelegate

    override func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        let superAnnotationView = super.mapView(mapView, viewFor: annotation)
        if let thisAnnotation = annotation as? MRPointAnnotation, thisAnnotation == userAnnotation {
            if let annotationView = mapView.dequeueReusableAnnotationView(withIdentifier: "a") {
                return annotationView
            }
            let annotationView = MRAnnotationView.init(annotation: userAnnotation, reuseIdentifier: "a")
            annotationView.frame = CGRect(x: 0, y: 0, width: 10, height: 10)
            annotationView.backgroundColor = UIColor.blue
            return annotationView
        }
        return superAnnotationView
    }
}
